censored_words_rus = (
    # Основные слова
    'блядь', 'блять', 'бля', 'блядина', 'блядки', 'блядовать',
    'сука', 'сучка', 'сучара', 'сучонка',
    'пидор', 'пидорас', 'пидарас', 'педик', 'педрила', 'петух', 'голубой',
    'гандон', 'говно', 'говнюк', 'говноед',
    'хуй', 'хуйло', 'хуесос', 'хуёвый', 'хуёво', 'хуяк', 'хуячить',
    'ебать', 'ебаный', 'ебанный', 'ебло', 'ебало', 'еблан', 'ебучий',
    'нахуй', 'нахер', 'нахрен', 'похуй', 'похер', 'похрен',
    'мудак', 'мудило', 'мудозвон',
    'залупа', 'залупоголовый',
    'дрочить', 'дрочка', 'дрочила',
    'шлюха', 'шалава', 'проститутка',
    'урод', 'уродина',
    'тварь', 'скотина',
    'мразь', 'гад', 'подонок',
    'лох', 'лошара', 'лохматый',
    'чмо', 'чмошник',
    'отстой', 'дерьмо', 'мерзость',
    # Часто используемые замены (латиница, символы и т.п.)
    'blyat', 'blyad', 'suka', 'pidor', 'gandon', 'huilo', 'huesos',
    'ebanyy', 'pizda', 'pzdets', 'xyu', 'xuy', 'xyilo', 'xyesos',
)

toxic_emoji = ['🤡', '💩']

reverso_word = {}



import re
from .words import censored_words_rus

class NotPotty:

    word_list = '|'.join(re.escape(word) for word in censored_words_rus)
    CENSOR_PATTERN = re.compile(rf'\b(?:{word_list})\b', re.IGNORECASE)

    def ffirstone(self, text):
        """Метод для поиска нецензурного слова"""
        match = self.CENSOR_PATTERN.search(text)
        if match:
            return match.group()
        return None

    @staticmethod
    def ffirst_one(text):
        """Метод для поиска нецензурного слова"""
        match = NotPotty.CENSOR_PATTERN.search(text)
        if match:
            return match.group()
        return None


    def pfirstone(self, text):
        """Метод для поиска нецензурного слова и вывода"""
        match = self.CENSOR_PATTERN.search(text)
        message = "Нецензурных слов нет"
        if match:
            message =f"Найдено нецензурное слово: {match.group()}"
            return message
        return message


    def sensor(self, text):
        """Метод сканирования нецензурного слова"""
        match = self.CENSOR_PATTERN.search(text)
        if match:
            return True
        return False
